@@ -43,8 +43,9 @@ pub struct SyntaxReferenceInSet<'a> {
     pub syntax_set: &'a SyntaxSet,
 }
 
-/// Compress for size of ~700 kB instead of ~4600 kB at the cost of ~30% longer deserialization time
-pub(crate) const COMPRESS_SYNTAXES: bool = true;
+/// Lazy-loaded syntaxes are already compressed, and we don't want to compress
+/// already compressed data.
+pub(crate) const COMPRESS_SYNTAXES: bool = false;
 
 /// We don't want to compress our [LazyThemeSet] since the lazy-loaded themes
 /// within it are already compressed, and compressing another time just makes
@@ -90,7 +91,8 @@ impl HighlightingAssets {
         self.fallback_theme = Some(theme);
     }
 
-    fn get_syntax_set(&self) -> Result<&SyntaxSet> {
+    /// Return the collection of syntect syntax definitions.
+    pub fn get_syntax_set(&self) -> Result<&SyntaxSet> {
         self.syntax_set_cell
             .get_or_try_init(|| self.serialized_syntax_set.deserialize())
     }
@@ -186,7 +188,8 @@ impl HighlightingAssets {
         }
     }
 
-    pub(crate) fn get_theme(&self, theme: &str) -> &Theme {
+    /// Look up a syntect theme by name.
+    pub fn get_theme(&self, theme: &str) -> &Theme {
         match self.get_theme_set().get(theme) {
             Some(theme) => theme,
             None => {
@@ -579,13 +582,22 @@ mod tests {
     }
 
     #[test]
-    fn syntax_detection_is_case_sensitive() {
+    fn syntax_detection_is_case_insensitive() {
         let mut test = SyntaxDetectionTest::new();
 
-        assert_ne!(test.syntax_for_file("README.MD"), "Markdown");
+        assert_eq!(test.syntax_for_file("README.md"), "Markdown");
+        assert_eq!(test.syntax_for_file("README.mD"), "Markdown");
+        assert_eq!(test.syntax_for_file("README.Md"), "Markdown");
+        assert_eq!(test.syntax_for_file("README.MD"), "Markdown");
+
+        // Adding a mapping for "MD" in addition to "md" should not break the mapping
         test.syntax_mapping
             .insert("*.MD", MappingTarget::MapTo("Markdown"))
             .ok();
+
+        assert_eq!(test.syntax_for_file("README.md"), "Markdown");
+        assert_eq!(test.syntax_for_file("README.mD"), "Markdown");
+        assert_eq!(test.syntax_for_file("README.Md"), "Markdown");
         assert_eq!(test.syntax_for_file("README.MD"), "Markdown");
     }
 
